#
# spec file for package ghc-skylighting-core
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name skylighting-core
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.14.6
Release:        2.7
Summary:        Syntax highlighting library
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-attoparsec-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-base64-bytestring-prof
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-case-insensitive-prof
BuildRequires:  ghc-colour-devel
BuildRequires:  ghc-colour-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-safe-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-utf8-string-prof
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-xml-conduit-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-Diff-devel
BuildRequires:  ghc-Diff-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-pretty-show-devel
BuildRequires:  ghc-pretty-show-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-golden-prof
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
Skylighting is a syntax highlighting library. It derives its tokenizers from
XML syntax definitions used by KDE's KSyntaxHighlighting framework, so any
syntax supported by that framework can be added. An optional command-line
program is provided. Skylighting is intended to be the successor to
highlighting-kate. This package provides the core highlighting functionality
under a permissive license. It also bundles XML parser definitions licensed
under the GPL.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Jan 29 2025 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Jan  7 2025 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.6.
  [#]# 0.14.6
  * Export Skylighting.Format.Typst from Skylighting [API change] (#201).
    Allow typst as an output format in the cli executable.
* Mon Dec 23 2024 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.5.
  [#]# 0.14.5
  * Update xml syntax definitions for bash, cmake, commonlisp, isocpp,
    javascript-react, julia, latex, lua, markdown, modelines, nix, orgmode,
    php, python, rhtml, ruby, swift, xml, yaml, zig, zsh. Add odin (required
    by orgmode).
  * Update JSON syntax definition from upstream. (#203)
* Sun Dec  8 2024 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.4.
  [#]# 0.14.4
  * Add `gdscript`, `typst`, `tlaplus` syntax (#184, #199).
* Tue Sep 10 2024 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.3.
  [#]# 0.14.3
  * Add crystal, racket, zip syntax (#194).
* Mon Jun 24 2024 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.2.
  [#]# 0.14.2
  * Add `loadValidSyntaxesFromDir` (Kevin Quick) [API change].
    The `loadSyntaxesFromDir` function is an all-or-nothing function:
    a single invalid file results in a error and *no* loaded syntaxes.
    This adds the `loadValidSyntaxesFromDir`, which is resilient
    against individual syntax file load failures.  It returns a map
    of the failure messages, and the SyntaxMap that is created from
    all the successful parsing.
* Sat May 11 2024 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.1.2.
  [#]# 0.14.1.2
  * Add terraform syntax (#190).
* Thu Mar 14 2024 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.1.1.
  [#]# 0.14.1.1
  * Add GPRBuild syntax.
  * Update syntax descriptions for clojure, cmake, coffee, cpp,
    cs, erlang, graphql, haskell, javascript, julia, kotlin,
    lilypond, markdown, objectivec, objectivecpp, ocaml, perl,
    python, ruby, rust, stan, typescript, yaml.
* Mon Dec  4 2023 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.1.
  [#]# 0.14.1
  * Update syntax definitions for julia, actionscript, bash, cpp, css,
    djangotemplate, dosbat, groovy, html, ini, isocpp, java, javadoc, json,
    jsp, latex, makefile, mustache, php, powershell, rest, rhtml,
    sass, scala, scss, toml, xml, raku (with patch).
  * Many improvements to regular expression compilation:
  - Properly recognize unicode characters.
  - Handle `\Q..\E` literal sequences.
  - Handle group modifiers like `(?i:etc.)`. (The only one
    we actually pay attention to is `i`.)
  - Allow unicode category escapes outside of character classes.
  - Support one-letter unicode category escapes like `\p{L}`.
    These are found in some of the newer syntax definitions.
  * Improve regex matching:
  - Fix `wordDetect` to work around an issue in the new html.xml.
  - Refactor and fix `atWordBoundary`: remove redundant checks, and
    fix behavior (`/x\b/` was behaving like `/\bx\b/`) (Côme ALLART).
  - Fix bug in `lastCharOffset` (Côme ALLART).
  * Style: Allow colors to be specified in ARGB format (#178).
    We currently just ignore the A part, but at least we don't fail.
* Sun Aug 27 2023 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.14.
  [#]# 0.14
  * Add rWeakDeliminators field to Rule. [API change]
  * Make WordDetect sensitive to weakDeliminator. This fixes
    parsing of floats beginning with '0.' in C (#174).
  * Add debiancontrol syntax (#173).
* Fri Jul 21 2023 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.13.4.1.
  [#]# 0.13.4.1
  * Update syntax definitions: ada, bash, cmake, css, html, isocpp, java,
    javascript, kotlin, latex, makefile, markdown, php, python, qml, r,
    sass, scss, typescript, zsh.
  * Don't require word boundary at end of Int, Float, HlCHex, HlCOct (#170).
    KDE does not.  This fixes things like `7L` in R.
* Fri Jul  7 2023 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.13.4.
  [#]# 0.13.4
  * Add `dosbat` syntax (MS DOS batch file) (#169).
  * Derive `Bounded` Instance for `TokenType` (#168, Pavan Pikhi).
    Add `Bounded` to the derived instances for the `TokenType` type. This
    allows consumers to use `[minBound .. maxBound]` to generate a list of
    all token types when writing a `Style`.
  * Require xml-conduit >= 1.9.1.3. This fixes a bug that prevents
    parsing certain DOCTYPE declarations, e.g. in `agda.xml`.
  * Updated `cmake` syntax definition.
* Tue Jun 20 2023 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.13.3.
  [#]# 0.13.3
  * Add gap language (#167).
  * Update syntax definitions.
  * Add patches for agda.xml and dtd.xml, to wor around a bug in xml-conduit:
    https://github.com/snoyberg/xml/pull/187
  * Store compiled regexes in RE (#166, Jonathan Coates).
    This changes the RE type to (lazily) compile the regex when constructed,
    rather than in the tokenizer. This allows us to avoid re-compiling
    regexes for each separate tokenize call, instead sharing them globally.
    We try to hide the internals of this, exposing the previous interface
    `(RE { reString, reCaseSensitive })` with pattern synonyms.
  * ConTeXt: fix handling of spaces in non-normal tokens (Albert Krewinkel).
    This ensures that multiple spaces won't be collapsed into a single space.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Feb  8 2023 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.13.2.1.
  [#]# 0.13.2.1
  * Update tango style for new token types (#164). The original
    tango style didn't have colors defined for many token types
    that have been added since it was added.  This commit
    updates the style to support them. Thanks to @danbraswell
    for providing the values needed.
* Sun Dec 18 2022 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.13.2.
  [#]# 0.13.2
  * Support ConTeXt output via skylighting-format-context (Albert Krewinkel).
  * Update syntax definitions for markdown, nim, javascript.
  [#]# 0.13.1.2
  * Update syntax definitions for c, cmake, commonmlisp, css, go, ini, isocpp,
    javascript, json, powershell, python, rust, sass, scss, toml, xml.
  * Associate regex captures with a context. This is necessary for proper
    implementation of the KDE syntax highlighting algorithm.  Captures are
    only available within the context to which the match creating the
    capture switches. (Closes #160.)
* Fri Oct 28 2022 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.13.1.1.
  [#]# 0.13.1.1
  * Add dart, purescript syntax definitions.
  * Update syntax definitions for isocpp, latex, alert, bash,
    cmake, nix, sql-postgresql, vhdl, zsh.
  * Remove obsoleote patch for lua.xml.
  * Add patches for latex.xml and isocpp.xml.
  [#]# 0.13.1
  * `getCapture`: fail instead of throwing error if dynamic match not found.
    I believe this is the intended behavior for StringDetect, judging
    from examples in the KDE documentation.
  * Update xml syntax definitions:
    asn1, bash, c, cmake, cpp, cs, d, elixir, fortran-fixed, gcc, glsl,
    go, html, java, javascript, lex, lua, markdown, mediawiki, noweb,
    ocaml, orgmode, php, powershell, prolog, python, r, ruby, rust,
    scheme, sql-postgresql, typescript, vhdl, xml, yacc, yaml, zsh
  * Replace a lambda with pointfree notation (shaving off some RAM usage)
    (0xd34df00d).
  * Use `newtype` for `TokenizerM`, giving about 5-10%% boost on benchmark
    (0xd34df00d).
* Sat Aug 13 2022 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.13 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Jul 30 2022 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.13.
  [#]# 0.13
  * Update syntax definitions from upstream: bash, cmake, diff,
    ini, perl, php, sgml, xml.
  * Split out formatters into separate packages (#152). API changes:
  - Skylighting.Core no longer exports Skylighting.Format.ANSI,
    Skylighting.Format.HTML, Skylighting.Format.LaTeX.  These are
    now provided by separate packages, skylighting-format-ansi,
    skylighting-format-blaze-html, skylighting-format-latex.
  - Skylighting.Types no longer exports XTerm256ColorCode.
    This has been moved to skylighting-format-ansi.
  * Change Makefile to use cabal instead of stack.
* Thu May 19 2022 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.12.3.1.
  [#]# 0.12.3.1
  * Allow mtl 2.3.
  * Update syntax defs from upstream: bash, cmake, go, haxe, lua, zsh.
  * Add nix.xml (#149).
  * Add Pygments styles for `Import` and `BuiltIn` token types (#147,
    Bryan A. Danielak).
  * Use StrictData.
  * Remove unused dependencies (silences cabal warnings) (Andreas Abel).
* Fri Feb 18 2022 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.12.3.
  [#]# 0.12.3
  * Add scss, sass, systemverilog, orgmode.
  * Update xml definitions from upstream: bash, css, python, r, zsh.
* Wed Jan 19 2022 Peter Simons <psimons@suse.com>
- Update skylighting-core to version 0.12.2.
  [#]# 0.12.2
  * Parser: handle context shift to external context, e.g.,
    `BashOneLine##Bash`.  Closes #139 (issue with Dockerfile).
  * Update xml files from upstream:
    bash, cmake, markdown, objectivecpp, php, sql-postgresql, sql, stan, zshr
  * Fix formatting in `Color` doc-comment (Janek Spaderna).
  * Add stan.xml (Brian Ward).
* Mon Nov  1 2021 psimons@suse.com
- Update skylighting-core to version 0.12.1.
  [#]# 0.12.1
  * Update syntax definitions:  bash, cmake, dockerfile,
    gnuassembler, markdown, spdx-comments.
  * Support hex escapes using `\x` in regex char classes (#135).
    These occur in a number of syntax definitions and weren't
    correctly interpreted before. Thanks to @Agnishom.
  * Support regex property syntax, e.g. `\p{Lu}`.
  * Regex: support `\B` (non-word-boundary).
* Mon Sep 20 2021 psimons@suse.com
- Update skylighting-core to version 0.12.
  [#]# 0.12
  * Properly handle include elements in keyword lists (#124).
    A number of syntaxes (e.g. typescript, scala) include keyword
    lists from other syntaxe,s and previously we weren't able to
    handle this.
    There are several pieces to this change.  We need to store lists
    where other Syntaxes can look them up, so we add an `sLists`
    field to `Syntax` [API change], and modify the parser to fill this.
    We change lists so that their values are not just a `Text`, but a
    `ListItem` that can either be a textual value or an include directive,
    specifying a `ListName` (syntax name and list name).
    The `Keyword` constructor for `Matcher` now takes, instead of a
    `WordSet`, Either a `ListName` or a `WordSet` (API change).
    Skylighting.Parser now exports `resolveKeywords` (API change),
    which modifies all `Keyword` matchers in a syntax so that Left
    values with a `ListName` become Right values with resolved `WordSet`s.
    The tokenizer applies this function automatically to the SyntaxMap
    given in Config.  But it is more efficient to do this conversion
    just once, rather than every time `tokenize` is called. So we have
    `loadSyntaxesFromDir` call it on the `SyntaxMap`.  With this
    optimization, there is not an appreciable performance cost to the
    changes described above.
  * Skylighting.Regex: Fix bug with regexes like `a{10}b` (#133).
    This requires exactly 10 a's; previously we interpreted it as
    "at least 10."
  * skylighting-extract: take a directory as argument rather than files.
    This allows us to use `loadSyntaxesFromDir`.
  * Update xml syntax definitions from upstream:
    julia, cmake, cpp, isocpp, markdown, python, toml.
* Mon Jul 19 2021 psimons@suse.com
- Update skylighting-core to version 0.11.
  [#]# 0.11
  * Skylighting.Regex: Support regex subroutines (#118).  For example,
    `(?1)` is replaced by the regex in the first capturing group.  So far
    we only support this simple, absolute form, not the relative
    form `(?-1)` supported by some engines (but not used, I think, in
    KDE's syntax highlighters).  This change involves an API change:
    Regex in Skylighting.Regex has a new Subroutine constructor,
    and the Recurse constructor has been removed.  Instead of Recurse we use
    Subroutine 0, which unifies the code.
  * Skylighting.Regex: handle e.g. `[\1]` and `[\123]` (without
    initial 0) as octal escapes (#118).  These occur in the zsh.xml
    syntax definition.
  * Pull xml definitions for bash, cmake, python, zsh from upstream.
  * README: Add a note about pulling syntax definitions from upstream (#138).
    Update build instructions for recent cabal versions (#131).
* Mon Jun 21 2021 psimons@suse.com
- Update skylighting-core to version 0.10.5.2.
  [#]# 0.10.5.2
  * Added swift grammar definition (Igor Ranieri).
  * Simplify README.md instructions for two-step build.
  * Fix link to KDE documentation.
* Tue Mar 23 2021 psimons@suse.com
- Update skylighting-core to version 0.10.5.1.
  [#]# 0.10.5.1
  * Regex: Allow lookaheads to capture groups.  Previously
    captures in lookaheads, like `(?=(a*))`, were ignored.  This
    led to errors highlighting xml and probably other formats (#121).
  * Throw an exception if a capture group isn't defined (with 'dynamic')
    rather than simply having getCapture fail so that the rule fails.
    This will make it easier to debug issues like #121.
* Mon Mar 22 2021 psimons@suse.com
- Update skylighting-core to version 0.10.5.
  [#]# 0.10.5
  * Fix regression from 0.10.3 with Haskell highlighting of Char (#120).
  * Update xml syntax definitions from upstream.  Updated
    syntaxes: abc apache asp bash bibtex boo c changelog clojure
    cmake commonlisp cs curry d diff djangotemplate doxygen
    elixir elm email erlang fortran-fixed fortran-free fsharp
    hamlet haskell haxe html idris ini javascript-react
    javascript json julia kotlin latex lex lilypond
    literate-curry literate-haskell makefile markdown
    mathematica maxima mediawiki metafont modula-2 mustache nasm
    nim noweb ocaml octave opencl perl powershell prolog pure
    python r roff ruby rust sed spdx-comments sql-mysql
    sql-postgresql tcl tcsh toml typescript verilog xml xslt xul
    yacc yaml.  Not updated: rhtml (causes an error on our test
    suite), zsh (has a regex we can't parse).
* Sun Mar 14 2021 psimons@suse.com
- Update skylighting-core to version 0.10.4.1.
  [#]# 0.10.4.1
  * Fixed logic for checking line-end-context (#119).
  * Use NonEmpty for the context stack.
  * Remove unneeded build-depends.
* Tue Mar  2 2021 psimons@suse.com
- Update skylighting-core to version 0.10.4.
  [#]# 0.10.4
  * Move from hxt to xml-conduit for XML parsing.
    This gives about a 4X speedup in parsing syntax definitions.
    It also reduces the pandoc build dependency footprint, as we
    depend on xml-conduit anyway and now no longer need to compile
    HXT and its dependencies.
    There are improvements in accuracy as well: the change to
    xml-conduit improved parsing for one of the prolog rules;
    a matcher that should have been for tab characters had been set for a
    space instead.
  * Removed some unnecessary build-depends in skylighting-extract.
* Tue Feb 23 2021 psimons@suse.com
- Update skylighting-core to version 0.10.3.
  [#]# 0.10.3
  * Add support for raku (#114).
  * Reimplement PR #40 and add haskell.xml.patch (#116).
  * Update syntax definitions: actionscript ada asp awk bash
    bibtex boo c cmake cpp cs d elm email fasm fsharp glsl
    gnuassembler go haskell haskell idris isocpp
    javascript julia latex lilypond makefile mediawiki metafont
    mustache objectivec objectivecpp octave opencl perl php
    php powershell prolog purebasic raku rest ruby sed
    spdx-comments sql-mysql sql-postgresql sql typescript
    verilog vhdl.
  * Fix php.xml.patch so it applies again.
* Fri Dec 18 2020 psimons@suse.com
- Update skylighting-core to version 0.10.2.
  [#]# 0.10.2
  * Update syntax definitions for abc, actionscript, asn1, ats,
    bash, boo, coffee, comments, cpp, cs, css, curry, d,
    djangotemplate, dockerfile, doxygen, dtd, elixir, graphql,
    groovy, hamlet, haskell, haxe, idris, ini, j, java,
    javadoc, javascript-react, javascript, jsp, kotlin, lex,
    lilypond, literate-curry, literate-haskell, m4, makefile,
    mandoc, markdown, mediawiki, mips, modula-2, modula-3,
    monobasic, mustache, nim, noweb, objectivec, objectivecpp,
    ocaml, opencl, pascal, perl, php, pike, postscript,
    prolog, protobuf, pure, purebasic, python, qml, relaxng,
    relaxngcompact, rest, rhtml, roff, ruby, scala, sci, sed,
    sgml, sml, spdx-comments, stata, tcsh, texinfo, verilog,
    xml, xorg, xul.
  * Re-insert CSS line needed to make line numbers appear in
    HTML.  See jgm/pandoc#6625.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Nov 25 2020 psimons@suse.com
- Update skylighting-core to version 0.10.1.
  [#]# 0.10.1
  * Regex: handle `(?|)` modifier.  This is used in bash.xml now.
    It resets the numbers of capturing groups in alternatives.
  * Improve regex handling of `{` and `}` not in quantifiers:
  - `{}` is literal (not a quantifier).
  - loose unescaped `{` and `}` that are not part of a quantifier are
    literal matchers.
  * Update xml syntax definitions from upstream.
    For: abc, actionscript, ada, agda, alert, apache, asn1, asp,
    ats, awk, bash, boo, c, clojure, cmake, coffee, coldfusion,
    commonlisp, cs, css, curry, d, djangotemplate, dockerfile,
    dot, doxygen, dtd, eiffel, elixir, elm, erlang, fasm,
    fortran-fixed, fortran-free, fsharp, glsl, gnuassembler, go,
    graphql, groovy, hamlet, haskell, haxe, html, idris, ini,
    isocpp, j, java, javadoc, javascript, jsp, julia, kotlin,
    latex, lex, lilypond, literate-curry, literate-haskell,
    llvm, lua, m4, makefile, markdown, mathematica, matlab,
    maxima, mediawiki, metafont, mips, modula-2, modula-3,
    monobasic, mustache, nasm, nim, noweb, objectivec,
    objectivecpp, ocaml, octave, opencl, pascal, perl, php,
    pike, postscript, povray, powershell, prolog, protobuf,
    pure, purebasic, python, r, relaxng, relaxngcompact, rest,
    rhtml, roff, ruby, rust, scala, scheme, sci, sed, sgml, sml,
    sql-mysql, sql-postgresql, sql, stata, tcl, tcsh, texinfo,
    toml, verilog, vhdl, xml, xorg, xslt, xul, yacc, yaml, zsh.
    Also added spdx-comments.xml and comments.xml, which are
    needed for these.  Closes #111 (latex bug in matrix).
* Fri Oct 23 2020 psimons@suse.com
- Update skylighting-core to version 0.10.0.3.
  [#]# 0.10.0.3
  * Add groovy syntax.
* Tue Oct 13 2020 psimons@suse.com
- Update skylighting-core to version 0.10.0.2.
  [#]# 0.10.0.2
  * Improve DetectIdentifier to ensure that identifiers can't
    include non-ASCII characters.
  [#]# 0.10.0.1
  * Fix identifier detection in non-ASCII context (#110).
  [#]# 0.10
  * Add instructions for submitting patches upstream to KDE (#106).
  * Synced syntax definitions from KDE repo.  Note that fortran
    has split into two: `fortran-fixed` and `fortran-free`.
  * Add test to ensure that all regexes in rules compile.
  * Regex: allow unescaped `}`.
  * Regex: allow empty regexes and groups.
  * Regex: support lazy and possessive quantifiers (#109).
  * Regex: support recursive regexes `(?R)` (#108).
  * Hide invisible line numbers from keyboard focus (#107, d10n).
    This fixes tabbing through elements on a page.
  * Remove some obsolete patches for xml definitions.
  [#]# 0.9
  * Use a pure Haskell regex implementation (in unexported module
    Text.Regex.KDE) instead of pcre.  The implementation is not
    as efficient as pcre, but it seems good enough for this
    application, and it is desirable to avoid depending on a C
    library.  (Available Haskell libraries weren't up to the
    task, because they don't do back-references, captures,
    lookahead/behind.) Some benchmarks (old/new):
    haskell (4.6/7.9) java (13.4/23.3) c (2.8/3.7) rhtml
    (4.7/6.1) lua (10.6/13.2) javascript (4.2/6.6).
    Though this is a significant slowdown, the tradeoff seems
    worth it to have a pure Haskell implementation.
  * Removed old `system-pcre` flag.
  * More efficient treatment of dynamic regexes.
    We put something in the Regex itself to represent the `%%1`,
    and modify it later.  This allows us to cache dynamic
    regexes in a way we couldn't before.
  * Add support for TOML (#105, Shiming Wang),
    GraphQL, and Nim syntax (#102, Daniel Pozo Escalona).
  * Update xml definitions for actionscript, bash, boo, c,
    cmake, elm, erlang, glsl, isocpp, java, lua, m4, mediawiki,
    perl, powershell, scala, tcsh, xul, zsh.
  * Fix fallthrough behavior (don't always consume a token).
  * Fix word boundary detection.
  * Remove RegexException. (API change)
  * Skylighting.Regex now exports `isWordChar` and `testRegex`,
    as well as the constructors underlying the new `Regex` type.
  * Remove some obsolete xml definition patches.
  * Fix escaped %% in dynamic regex.
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 6GB min disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Sun Jun 21 2020 psimons@suse.com
- Update skylighting-core to version 0.8.5.
  [#]# 0.8.5
  * Respect dynamic flag on StringDetect elements (#99, Albert
    Krewinkel).
  * Increase test timeout to avoid failures with qemu-emulated
    environments, such as qemu and riscv64 in Ubuntu builders
    (William Grant).
  * Fix attribute for opening double quote in sql-postgresql.xml
    (Benjamin Wuethrich).
  * Update syntax descriptions for javascript, bash, coffee,
    javascript-react, javascript, latex, sql-postgresql, typescript.
* Tue Jun  9 2020 psimons@suse.com
- Update skylighting-core to version 0.8.4.
  [#]# 0.8.4
  * HTML output: use aria-hidden="true" on empty a elements
    unless numberLines is specified (in which case the element
    is still empty but will have content added by CSS).
    This is to avoid excess noise when the code blocks are
    read by screen readers.  See jgm/pandoc#6352.
* Wed May  6 2020 psimons@suse.com
- Update skylighting-core to version 0.8.3.4.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/skylighting-core-0.8.3.4/src/changelog.md
* Sat Jan 25 2020 psimons@suse.com
- Update skylighting-core to version 0.8.3.2.
  [#]# 0.8.3.2 -- 2020-01-21
  * This fixes a packaging error in 0.8.3.1, which didn't include
    the results of the bootsrap step and hence didn't update the
    syntax modules.
  [#]# 0.8.3.1 -- 2020-01-21
  * Escape `<` and `>` in latex to avoid ligatures (#91).
  * Fix and extend Idris keywords (Denis Buzdalov).
  * Update XML syntax definitions for javascript-react, qml,
    typescript, javascript, cmake, cofee, latex, perl, python,
    rest.
  * Fixed bug with context shifts using `##` syntax for foreign context.
    Previously we only handled these in IncludeRules, but
    starting with the current batches of xml files they can occur
    elsewhere too.
* Wed Nov 27 2019 psimons@suse.com
- Update skylighting-core to version 0.8.3.
  [#]# 0.8.3 -- 2019-11-26
  * Update XML syntax definitions for c, cmake, coffee, cpp, css,
    diff, djangotemplate, elixir, elm, glsl, haskell, html, isocpp,
    javascript-react, javascript, json, jsp, julia, latex, lua,
    markdown, matlab, mediawiki, modelines, mustache, perl, php,
    powershell, qml, rest, rust, typescript, vhdl.
  * Fix highlighting errors with non-ASCII characters in JSON (#90).
    This error was due to an optimization that made some incorrect
    assumptions.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Oct  4 2019 psimons@suse.com
- Update skylighting-core to version 0.8.2.3.
  [#]# 0.8.2.3 -- 2019-10-03
  * Tests: ensure we read test files as UTF-8.
  * Fix compiler warnings around Monoid imports.
  * Add MonadFail constraint (allowing compilation with ghc 8.8.x).
  * Add cabal.project and move CI from Travis to GitHub Actions.
* Wed Oct  2 2019 psimons@suse.com
- Update skylighting-core to version 0.8.2.2.
  [#]# 0.8.2.2 -- 2019-09-30
  * Remove upper bound on regex-base and require
    regex-pcre-builtin >= 0.95, to avoid a build conflict
    with earlier versions of regex-pcre-builtin and
    regex-base >= 0.94.
  * Remove unused system-pcre flag in skylighting.cabal.
    This flag only affects skylighting-core.
* Thu Sep 26 2019 psimons@suse.com
- Update skylighting-core to version 0.8.2.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/skylighting-core-0.8.2.1/src/changelog.md
* Mon Jul 15 2019 psimons@suse.com
- Update skylighting-core to version 0.8.2.
  [#]# 0.8.2 -- 2019-07-14
  * Change matchRegex so it gives "no match" on a regex error
    instead of raising an exception. This seems to be how Kate
    works.  Fixes an error on long integer literals (#81).
  [#]# 0.8.1.2 -- 2019-07-14
  * Fix HlCChar for one-character octal escapes like '\0' (#82).
    Due to a bug in pCStringChar, only multi-character octal
    escapes were being recognized. This affects not just C
    highlighting, but all of the following highlighters which
    use HlCChar: fasm eiffel pike objectivec ruby vhdl scala
    java jsp nasm protobuf pure go objectivecpp gnuassembler povray
    actionscript c cs opencl boo rhtml elixir.  This fixes a
    regression introduced in version 0.3.1.
* Fri Jun 14 2019 psimons@suse.com
- Update skylighting-core to version 0.8.1.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/skylighting-core-0.8.1.1/src/changelog.md
* Sat Mar  2 2019 psimons@suse.com
- Update skylighting-core to version 0.7.7.
  [#]# 0.7.7 -- 2019-02-27
  * Add parseSyntaxDefinitionFromString [API change].
  * Fix parseSyntaxDefinition so that language.dtd no longer needed.
    We strip out the SYSTEM "language.dtd" part of the doctype
    if present, leaving any inline entity definitions.
    This applies to both parseSyntaxDefinition and
    parseSyntaxDefinitionFromString.
  * Revised documentation of bootstrap build.
  * Makefile - fix bootstrap target.
  * Use FilePath instead of String for path (#64, anchpop).
* Sun Feb 10 2019 psimons@suse.com
- Update skylighting-core to version 0.7.6.
  [#]# 0.7.6 -- 2019-02-08
  * Update xml definitions for C, CPP, D, Haskell, Maxima, PHP,
    Ruby, Typescript.
  * Fix regex problem in erlang.xml (#63).
  * Export WordSet constructors (#62, Chris Martin).
  * Add support for protobuf (#60).
* Sun Dec  2 2018 psimons@suse.com
- Update skylighting-core to version 0.7.5.
  [#]# 0.7.5 -- 2018-12-01
  * Updated definitions for cmake, lua, prolog, rust, yacc,
    javascript.
  * Added definition for sml (#53).
  * Added definition for J (#50).
  * Added definition for typescript (#57).
  * Fix comments preceded by multiple spaces in bash.xml (#54).
  * Add *.txt extension and text/plain mime type to default.xml
    (#48).
  * Add file:/// if we have a Windows path with a drive.
    Otherwise HXT will take it to be a URI.  See jgm/pandoc#4836.
* Wed Oct 10 2018 psimons@suse.com
- Update skylighting-core to version 0.7.4.
  [#]# 0.7.4 -- 2018-10-08
  * HTML output: use title instead of data-line-number.
    data- attributes are not valid HTML 4, and we would like this to
    work with HTML 4 (e.g. in epub v2).  See jgm/pandoc#4920.
  * Print FALLTHROUGH in --trace output.
  * Updated syntax definitions for actionscript, awk, bash, c, clojure, cmake,
    coffee, cs, css, dockerfile, email, fortran, gcc, haskell, ini, isocpp,
    java, javadoc, javascript, jsp, kotlin, latex, lua, mediawiki, modelines,
    modula-2, objectivec, objectivecpp, opencl, perl, powershell, prolog,
    python, r, rest, rhtml, ruby, rust, scala, sql-mysql, sql-postgresql, sql,
    tcl, vhdl, xml, xul, yaml, zsh.
* Thu Aug 30 2018 psimons@suse.com
- Update skylighting-core to version 0.7.3.
  [#]# 0.7.3 -- 2018-08-27
  * Add 'default.xml' to syntax descriptions.
  * Raise base lower bounds to 4.8.  Drop support for ghc 7.8.
  * Use absolute number for cabal version, as now required.
* Fri Jul 13 2018 psimons@suse.com
- Update skylighting-core to version 0.7.2.
  [#]# 0.7.2 -- 2018-06-08
  * Update syntax definitions from upstream.
  * Added support for POV-Ray syntax (#46).
  * Display line numbers without absolute positioning (David
    Baynard, #32).
* Mon May 14 2018 psimons@suse.com
- Add skylighting-core at version 0.7.1.
